//*****************************************************************************
// Description     : Definition of IO functions
// Target Device   : APN504X
// Target Platform : Linux, C
// Date            : August 2017
// Version         : 1.0
//*****************************************************************************
#include <stdio.h>
#include <stdlib.h>
#include <string.h>

#include "file.h"
#include "local_define.h"


//#########################################################################
//  Name      : file_write_header
//  Function  : write header to the text file
//  Arguments :
//      in pName    : file name
//      in now_time : actual measurement time(msec)
//      in in_cps   : pointer to the array of input count rate(cps)
//      in th_cps   : pointer to the array of throughput count rate(cps)
//  Return :
//       0 : success
//      -1 : failed to open file
//#########################################################################
int file_write_header(char *pName, unsigned int now_time,
                      unsigned int *in_cps, unsigned int *th_cps)
{
    FILE *fp;

    // open file(create)
    fp = fopen(pName, "wt");
    if (fp == NULL) {
        return(-1);
    }

    // write header information
    fprintf(fp, "[header]\n");
    fprintf(fp, "Real time(s), %d\n", now_time/1000);
    fprintf(fp, "Input rate(cps), %d, %d, %d, %d\n", *in_cps, *(in_cps+1), *(in_cps+2), *(in_cps+3) );
    fprintf(fp, "Throughput rate(cps), %d, %d, %d, %d\n", *th_cps, *(th_cps+1), *(th_cps+2), *(th_cps+3) );

    // close file
    fclose(fp);

    return(0);
}


//#########################################################################
//  Name      : file_write_data
//  Function  : write data to the text file
//  Arguments :
//      in pName : file name
//      in chnum : number of CHs
//      in pBuff : array of data
//  Return :
//       0 : success
//      -1 : failed to open file
//      -2 : failed to seek
//#########################################################################
int file_write_data(char *pName, int chnum, unsigned int pBuff[][NUM_DATA])
{
    FILE *fp;
    int  ret;
    int  i, j;
    unsigned int *p;

    // open file(append)
    fp = fopen(pName, "rt+");
    if (fp == NULL) {
        return(-1);
    }

    // move to end of the file
    ret = fseek(fp, (int)0, SEEK_END);
    if (ret != 0) {
        fclose(fp);
        return(-2);
    }

    // write data
	fprintf(fp, "[data]\n");
    for (i = 0; i < NUM_DATA; i++) {
	    fprintf(fp, "%d", pBuff[0][i]);         // CH1
		for (j = 1; j < chnum; j++) {
	        fprintf(fp, ",%d", pBuff[j][i]);    // CH2-
		}
        fprintf(fp, "\n");
    }

    // close file
    fclose(fp);

    return(i);
}
